Skip to contents

Writes a formatted `div` block to the quarto document. Format of the `div` block is determined by the `all.layouts` table.

Usage

create_div(div.num = "div2", all.layouts, xx)

Arguments

all.layouts

output of get_design

xx

defined as a global variable in create_section.

x

Character string, the label or variable name to include in the header. Defaults to `"vname"`.

Value

No return value, called for side effects (writes markdown text).

Details

If div name of `x` is not included in `all.layouts`, nothing will be printed for that div in the quarto document.