Skip to contents

Finds all objects in the global environment with names matching `"layout."`, parses them with [parse_design()], and combines them into a single data frame with a `TYPE` column derived from the object name.

Usage

get_design()

Value

A data frame containing all compiled layout designs with their associated type.

Details

Used in create_all_sections

See also

[parse_design()]