Skip to contents

This function reads DGF from an Excel file and returns the contents of the "DGF" sheet as a data frame.

Usage

load_dgf(filename = "DGF.xlsx")

Arguments

filename

A character string specifying the name of the Excel file to read. Defaults to `"DGF.xlsx"`.

Value

A data frame containing the data from the "DGF" sheet of the specified Excel file.