Skip to contents

Read rg_preview column of DGF and print preview in a table in the RG

Usage

paste_preview_chr(VNAME, LABEL = "PREVIEW")

Arguments

VNAME

A character string specifying the name of the variable whose properties are to be displayed.

LABEL

A character string (from layout.TYPE object) for the section title. Defaults to `"PREVIEW"`.

Value

This function does not return a value; it prints the formatted table to the RG as html code

Details

The function is an internal function of `create_div` in R/03-01-create-sections.R.