Print Properties of a Variable into RG
paste_properties.RdRead rg_properties column of DGF and print properties in a table in the RG
Arguments
- VNAME
A character string specifying the name of the variable whose properties are to be displayed.
- LABEL
A character string (from layout.TYPE object) for the section title. Defaults to `"PROPERTIES"`.
Details
The function is an internal function of create_div in R/03-01-create-sections.R.