Check and standardize design element length
check_length.RdEnsures a parsed design element has the correct length and structure. If only three elements are present, an empty string is appended as the fourth element. If the length is not four, an error is thrown.
Value
A named character vector of length four with names `"DIV"`, `"VNAME"`, `"LABEL"`, and `"FUNCTION"`.
Details
Used in parse_design.