Create a section for a variable
create_section.RdGenerates a formatted section in Quarto for a given variable. Uses layouts from `all.layouts` and content from `L` to construct div blocks.
Arguments
- VNAME
Character string, the name of the variable to create a section for. Defaults to `"EIN"`.
- all.layouts
Output of get_design().
- L
A named list of variable-specific content. `L[[VNAME]]` should be the output of `dgf_to_list( dgf )` where `dgf` is the dgf as a data frame.