Initialize design for each section
get_design.RdFinds all objects in the global environment with names matching `"layout."`, parses them with [parse_design()], and combines them into a single data frame with a `TYPE` column derived from the object name.
Details
Used in create_all_sections