Generate Statistics Based on Variable Type
get_stats.RdGenerates needed graphics for rg_stats column of the DGF. Used inside R/01-00-CREATE-DGF.R
Arguments
- VNAME
A character string specifying the name of the variable in the data frame. (From vname column of the DGF)
- df
A data frame containing the variable to be visualized.
- VCLASS
A character string indicating the class of the variable (e.g., "numeric", "factor", "logical", or other).