Write a message to a log file (and optionally the console)
log_message.RdAppends a timestamped message to a log file. By default, the message is also printed to the console for immediate feedback.
log_message.RdAppends a timestamped message to a log file. By default, the message is also printed to the console for immediate feedback.